<?php

namespace Drupal\tidy_html\EventSubscriber;

use Drupal\Core\Routing\AdminContext;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\tidy_html\TidyInterface;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\HttpKernel\Event\FilterResponseEvent;
use Symfony\Component\HttpKernel\KernelEvents;

/**
 * A response filter that beautifies HTML responses.
 *
 * Only HTML responses should be processed by this filter.  This is determined
 * exclusively by the Content-Type header of the response.
 *
 * @package Drupal\tidy\EventSubscriber
 */
class TidyResponseFilter implements EventSubscriberInterface {

  /**
   * The tidy service.
   *
   * @var \Drupal\tidy_html\TidyInterface
   */
  protected $tidy;

  /**
   * The routing admin context helper service.
   *
   * @var \Drupal\Core\Routing\AdminContext
   */
  protected $adminContext;

  /**
   * Creates a new tidy response filter object.
   *
   * @param \Drupal\tidy_html\TidyInterface $tidy
   *   The tidy service.
   */
  public function __construct(TidyInterface $tidy, AdminContext $admin_context) {
    $this->tidy = $tidy;
    $this->adminContext = $admin_context;
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return [KernelEvents::RESPONSE => 'onResponse'];
  }

  /**
   * Subscriber callback for the kernel response event.
   *
   * @param \Symfony\Component\HttpKernel\Event\FilterResponseEvent $event
   *   The event that was dispatched.
   */
  public function onResponse(FilterResponseEvent $event) {

    if ($this->adminContext->isAdminRoute()) {
      return;
    }

    $response = $event->getResponse();
    $content_type = $response->headers->get('Content-Type');
    if (stripos($content_type, 'text/html') === FALSE) {
      return;
    }

    $response->setContent($this->tidy->format($response->getContent()));
  }

}
