<?php

namespace Drupal\tidy_html\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

class TidySettingsForm extends ConfigFormBase {

  /**
   * The settings that are mutable through this form.
   */
  const SETTINGS = 'tidy_html.settings';

  /**
   * @inheritDoc
   */
  protected function getEditableConfigNames() {
    return [static::SETTINGS];
  }

  /**
   * @inheritDoc
   */
  public function getFormId() {
    return 'tidy_html_settings';
  }

  /**
   * {@inheritDoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config(static::SETTINGS);

    $form['indent'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Indent'),
      '#description' => $this->t('Should output be automatically indented?'),
      '#default_value' => $config->get('indent'),
    ];

    $form['indent-spaces'] = [
      '#type' => 'number',
      '#title' => $this->t('Indent spaces'),
      '#description' => $this->t('How many spaces should each block be indented by?'),
      '#default_value' => $config->get('indent-spaces'),
      '#min' => 0,
      '#max' => 2147483647,
      '#states' => [
        'visible' => [
          ':input[name="indent"]' => [
            'checked' => TRUE
          ],
        ],
      ],
    ];

    $form['wrap'] = [
      '#type' => 'number',
      '#title' => $this->t('Wrap'),
      '#description' => $this->t('How many characters should be allowed per line before wrapping?  (0 for unlimited)'),
      '#default_value' => $config->get('wrap'),
      '#min' => 0,
      '#max' => 2147483647,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritDoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->configFactory->getEditable(static::SETTINGS)
      ->set('indent', $form_state->getValue('indent'))
      ->set('indent-spaces', $form_state->getValue('indent-spaces'))
      ->set('wrap', $form_state->getValue('wrap'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
