<?php

namespace Drupal\tidy_html;

use Drupal\Core\Config\ConfigFactoryInterface;

/**
 * This class wraps an instance of a Tidy extension object.
 *
 * Note - if this module is *somehow* installed on a system without tidy or
 * if the module is installed and then the tidy php extension is removed from
 * the system, then a fallback \Drupal\tidy_html\ExtensionPlaceholder service
 * is injected instead.  The extension placeholder does no formatting, and the
 * cache needs to be cleared in order for the switchover to occur.
 *
 * @see https://www.php.net/manual/en/book.tidy.php
 *
 * @package Drupal\tidy
 */
class Tidy implements TidyInterface {

  const ALLOWED_OPTIONS = ['indent', 'indent-spaces', 'wrap'];

  /**
   * The tidy module configuration.
   *
   * @var \Drupal\Core\Config\ImmutableConfig $config
   */
  protected $config;

  /**
   * The tidy service.
   *
   * @var \tidy|\Drupal\tidy_html\ExtensionPlaceholder
   */
  protected $tidy;

  /**
   * Tidy constructor.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory service.
   * @param mixed $tidy
   *   A tidy object or a placeholder object.
   */
  public function __construct(ConfigFactoryInterface $config_factory, $tidy) {
    $this->config = $config_factory->get('tidy_html.settings');
    $this->tidy = $tidy;
  }

  /**
   * {@inheritdoc}
   */
  public function format($html) {
    $options = array_filter($this->config->get(), function($key) {
      return in_array($key, static::ALLOWED_OPTIONS);
    }, ARRAY_FILTER_USE_KEY);

    return $this->tidy->repairString($html, $options);
  }

}
