<?php

namespace Drupal\Tests\tidy_html\Unit;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Config\ImmutableConfig;
use Drupal\Tests\UnitTestCase;
use Drupal\tidy_html\Form\TidySettingsForm;
use Drupal\tidy_html\Tidy;

/**
 * Unit test cases for the tidy service.
 *
 * @package Drupal\Tests\tidy_html\Unit
 *
 * @group tidy_html
 */
class TidyTest extends UnitTestCase {

  /**
   * A mocked version of the tidy php extension.
   *
   * @var \tidy|\PHPUnit\Framework\MockObject\MockObject
   */
  protected $mockTidy;

  /**
   * The subject under test.
   *
   * @var \Drupal\tidy_html\TidyInterface
   */
  protected $instance;

  /**
   * {@inheritdoc}
   */
  protected function setUp() {
    parent::setUp();

    $this->mockTidy = $this->getMockBuilder(\tidy::class)
      ->disableOriginalConstructor()
      ->getMock();

    $config = $this->getMockBuilder(ImmutableConfig::class)
      ->disableOriginalConstructor()
      ->getMock();

    $config
      ->method('get')
      ->willReturn([]);

    /* @var $config_factory \Drupal\Core\Config\ConfigFactoryInterface|\PHPUnit\Framework\MockObject\MockObject */
    $config_factory = $this->getMockBuilder(ConfigFactoryInterface::class)
      ->disableOriginalConstructor()
      ->getMock();

    $config_factory
      ->method('get')
      ->with(TidySettingsForm::SETTINGS)
      ->willReturn($config);

    $this->instance = new Tidy($config_factory, $this->mockTidy);
  }

  /**
   * Test case for the beautify method.
   *
   * @covers \Drupal\tidy_html\Tidy::format
   */
  public function testBeautify() {
    $this->mockTidy
      ->expects($this->once())
      ->method('repairString')
      ->willReturn('Beautiful Mock Data');

    $expected = 'Beautiful Mock Data';
    $actual = $this->instance->format($expected);

    $this->assertEquals($expected, $actual);
  }

}
